@@ -15,7 +15,7 @@ from .alarm import Alarm
 from .menu import Menu
 from .selector import Selector
 from .label import Label
-from .page import Page
+from .controls_box import ControlsBox
 from .control import Control, ControlPosition
 from .button_group import ButtonGroup
 from .event_log import EventLog, EventData
